//@TODO big todo is we need to fix the requirement for an Arc<RpcClient> things will be much
//cleaner without it.

pub mod bitcoin;
pub mod ethereum;
pub mod ethereum_classic;
pub mod handshake;
pub mod nimiq;
pub mod ravencoin;
pub mod siacoin;
pub mod chia;
pub mod turtl;
pub mod starcoin;
